@@ -2,22 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 2011 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2010 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2009 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2008 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2007 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2006 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2005 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2004 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2002 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2001 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1996 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2015 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
@@ -45,7 +30,7 @@
 #define __LZO1C_H_INCLUDED 1
 
 #ifndef __LZOCONF_H_INCLUDED
-#include "lzoconf.h"
+#include <lzo/lzoconf.h>
 #endif
 
 #ifdef __cplusplus
@@ -61,7 +46,7 @@ extern "C" {
  * When the required size is 0, you can also pass a NULL pointer.
  */
 
-#define LZO1C_MEM_COMPRESS      ((lzo_uint32) (16384L * lzo_sizeof_dict_t))
+#define LZO1C_MEM_COMPRESS      ((lzo_uint32_t) (16384L * lzo_sizeof_dict_t))
 #define LZO1C_MEM_DECOMPRESS    (0)
 
 
@@ -136,7 +121,7 @@ lzo1c_9_compress        ( const lzo_bytep src, lzo_uint  src_len,
 // better compression ratio at the cost of more memory and time
 ************************************************************************/
 
-#define LZO1C_99_MEM_COMPRESS   ((lzo_uint32) (65536L * lzo_sizeof_dict_t))
+#define LZO1C_99_MEM_COMPRESS   ((lzo_uint32_t) (65536L * lzo_sizeof_dict_t))
 
 LZO_EXTERN(int)
 lzo1c_99_compress       ( const lzo_bytep src, lzo_uint  src_len,
@@ -144,7 +129,7 @@ lzo1c_99_compress       ( const lzo_bytep src, lzo_uint  src_len,
                                 lzo_voidp wrkmem );
 
 
-#define LZO1C_999_MEM_COMPRESS  ((lzo_uint32) (5 * 16384L * sizeof(short)))
+#define LZO1C_999_MEM_COMPRESS  ((lzo_uint32_t) (5 * 16384L * sizeof(short)))
 
 LZO_EXTERN(int)
 lzo1c_999_compress      ( const lzo_bytep src, lzo_uint  src_len,
@@ -160,4 +145,4 @@ lzo1c_999_compress      ( const lzo_bytep src, lzo_uint  src_len,
 #endif /* already included */
 
 
-/* vim:set ts=4 et: */
+/* vim:set ts=4 sw=4 et: */
